pub fn sync_to_disk() -> Result<()>Expand description
Flushes and syncs file logs to disk through the logging thread.
This is a no-op when logging is not initialized or file logging is disabled.
Errors
Returns an error if the sync request cannot be delivered or acknowledged.